<p align="center">
  <a href="https://n3pdf.github.io/yadism/"><img alt="Yadism" src="https://raw.githubusercontent.com/N3PDF/yadism/master/docs/_assets/logo/logo.png" width=600></a>
</p>

<p align="center">
  <a href="https://github.com/N3PDF/yadism/actions?query=workflow%3A%22yadism%22"><img alt="Tests" src="https://github.com/N3PDF/yadism/workflows/yadism/badge.svg"></a>
  <a href='https://yadism.readthedocs.io/en/latest/?badge=latest'><img src='https://readthedocs.org/projects/yadism/badge/?version=latest' alt='Documentation Status' /></a>
  <a href="https://pypi.org/project/yadism/"><img alt="PyPI" src="https://img.shields.io/pypi/v/yadism"/></a>
  <a href="https://codecov.io/gh/N3PDF/yadism"><img src="https://codecov.io/gh/N3PDF/yadism/branch/master/graph/badge.svg?token=qgCFyUQ6oG" /></a>
  <a href="https://www.codefactor.io/repository/github/n3pdf/yadism"><img src="https://www.codefactor.io/repository/github/n3pdf/yadism/badge?s=e5a00668b58574b5b056e1aca01c7b25d2c203f8" alt="CodeFactor" /></a>
  <a href="https://zenodo.org/badge/latestdoi/219968694"><img src="https://zenodo.org/badge/219968694.svg" alt="DOI"></a>
</p>

<!--Future Badges
/github/workflow/status/N3PDF/dis/yadism

use the ones provided by shields.io:
- example: https://img.shields.io/github/workflow/status/N3PDF/yadism

note: in order to make shields.io the repo must be public (or accessible to it in some way)

optional:
- Release-date (github):
  - /github/release-date/:user/:repo
- Downloads:
  - github: /github/downloads/:user/:repo/total
  - pypi: /pypi/:period/:packageName
- License:
  - pypi-license: /pypi/l/:packageName
  - github-license: /github/license/:user/:repo
- Activity:
  - open-issues (github): /github/issues/:user/:repo
  - open-pull-requests (github): /github/issues-pr/:user/:repo
- Code size:
  - github: /github/languages/code-size/:user/:repo
-->

## Scope of the project

Provide all necessary tools to compute the DIS structure functions and related objects. This project is linked closely to [EKO](https://github.com/N3PDF/eko).

## Installation

As a user please use [the released version on PyPI](https://pypi.org/project/yadism/),
through your python package manager, e.g. with `pip`:

```sh
pip install yadism
```

### Dev

For development just use the install script and poetry (provided by install
script):

```sh
python install.py
poetry install
```

## Development

Members of the development team should always follow the [contribution
guidelines](.github/contributing.md), to have a uniform strategy in code
development and improve collaboration.

## Contributing or contacting the authors

For any kind of interaction consider before to read [external contribution
guidelines](.github/contributing.md#external-contributions), otherwise just send
an email to the authors:

- [Alessandro Candido](mailto:alessandro.candido@mi.infn.it)
- [Felix Hekhorn](mailto:felix.hekhorn@mi.infn.it)
- [Giacomo Magni](mailto:gmagni@nikhef.nl)
